# AI JSON – meta

This is a metapackage.

`pip install aijson-meta` is a shortcut for installing:
- [`aijson-core`](https://github.com/aijson/aijson) (core package)
- [`aijson-ml[api]`](https://github.com/aijson/aijson-ml) (LLM and transformers actionpack)
- [`aijson-db[all]`](https://github.com/aijson/aijson-db) (database actionpack)
- [`aijson-pdf[all]`](https://github.com/aijson/aijson-pdf) (PDF actionpack)
- [`aijson-utils[all]`](https://github.com/aijson/aijson-utils) (common utilities actionpack)
